@@ -95,6 +95,9 @@ public slots:
                          const QString     &strData);
     Q_NOREPLY void TextWithoutData (const QStringList &arrNumbers);
 
+    QStringList getTextsByDate(const QString &strStart, const QString &strEnd);
+    QStringList getTextsByContact(const QString &strContact);
+
 signals:
 
 public slots:
@@ -105,7 +108,6 @@ protected:
     friend class OsDependent;
 };
 
-
 class QGVDbusSettingsServer : public QDBusAbstractAdaptor
 {
     Q_OBJECT
